==> chicken_4.7.0.orig.tar.gz: private-namespace.scm <==
;;;; compiler-namespace.scm - A simple namespace system to keep compiler variables hidden
;
; Copyright (c) 2008-2011, The Chicken Team
; Copyright (c) 2007, Felix L. Winkelmann
; All rights reserved.
;
; Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following
; conditions are met:
;
;   Redistributions of source code must retain the above copyright notice, this list of conditions and the following
;     disclaimer. 
;   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following
;     disclaimer in the documentation and/or other materials provided with the distribution. 
;   Neither the name of the author nor the names of its contributors may be used to endorse or promote
;     products derived from this software without specific prior written permission. 
;
; THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS
; OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
; AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR
; CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
; CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
; SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
; THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
; OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
; POSSIBILITY OF SUCH DAMAGE.


(define-syntax private
  (lambda (form r c)
    (let ((namespace (cadr form))
	  (vars (cddr form)))
      (##sys#check-symbol namespace 'private)
      (let* ((str (symbol->string namespace)) ; somewhat questionable (renaming)
	     (prefix (string-append 
		      (string (integer->char (string-length str)))
		      (symbol->string namespace))))
	(for-each
	 (lambda (var)
	   (put! 
	    var 'c:namespace
	    (##sys#string->qualified-symbol prefix (symbol->string var))))
	 vars)
	'(##core#undefined) ) ) ) ) 

(set! ##sys#alias-global-hook
  (lambda (var . assign)		; must work with old chicken
    (or (get var 'c:namespace) var) ) )

==> chicken_4.8.0.orig.tar.gz: private-namespace.scm <==
;;;; compiler-namespace.scm - A simple namespace system to keep compiler variables hidden
;
; Copyright (c) 2008-2012, The Chicken Team
; Copyright (c) 2007, Felix L. Winkelmann
; All rights reserved.
;
; Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following
; conditions are met:
;
;   Redistributions of source code must retain the above copyright notice, this list of conditions and the following
;     disclaimer. 
;   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following
;     disclaimer in the documentation and/or other materials provided with the distribution. 
;   Neither the name of the author nor the names of its contributors may be used to endorse or promote
;     products derived from this software without specific prior written permission. 
;
; THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS
; OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
; AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR
; CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
; CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
; SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
; THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
; OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
; POSSIBILITY OF SUCH DAMAGE.


(define-syntax private
  (er-macro-transformer
   (lambda (form r c)
     (let ((namespace (cadr form))
	   (vars (cddr form)))
       (##sys#check-symbol namespace 'private)
       (let* ((str (symbol->string namespace)) ; somewhat questionable (renaming)
	      (prefix (string-append 
		       (string (integer->char (string-length str)))
		       (symbol->string namespace))))
	 (for-each
	  (lambda (var)
	    (put! 
	     var 'c:namespace
	     (##sys#string->qualified-symbol prefix (symbol->string var))))
	  vars)
	 '(##core#undefined) ) ) ) ) )

(set! ##sys#alias-global-hook
  (lambda (var . assign)		; must work with old chicken
    (or (get var 'c:namespace) var) ) )
